#!/usr/bin/env python
#
# This file is part of Practice Drills Template
# Author(s): Clare Richardson, Girlstart
# Copyright 2008
#
# Source code is part of Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for font, sound, and image sources.
#
# Practice Drills Template is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Practice Drills Template is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Practice Drills Template.  If not, see <http://www.gnu.org/licenses/>.

import pygame, random
from helpers import *

class ActivityGenerator(pygame.sprite.Sprite):
	def __init__(self,background_image):
		pygame.sprite.Sprite.__init__(self)
		self.screen = pygame.display.get_surface()
		self.area = self.screen.get_rect()
		self.background = background_image
		
		self.score = 0
		self.activity_count = 0
		self.correct_answer_count = 0

	def good_effect(self):
		self.score = self.score + 1
		display_static_image('good-picture.png',5,self.screen,self.background,self.area)

	def bad_effect(self):
		self.score = self.score - 1
		display_static_image('bad-picture.png',5,self.screen,self.background,self.area)

	def play(self,correct_answer):
		#default play will ask the user to press a specific key to complete the activity
		answered_correctly = False
		activity_completed = False
		
		while not activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					activity_completed = True
					if event.key == ord(correct_answer):
						answered_correctly = True
		
			# Draw everything to the screen
			self.screen.blit(self.background, (0, 0))

			font = pygame.font.Font(None, 30)
			text = font.render("Press the '" + correct_answer + "' key to complete this activity correctly.", 1, (0,0,0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,self.area.centery
			self.screen.blit(text, textrect)
			
			pygame.display.flip()

		self.activity_count += 1
		if answered_correctly:
			self.correct_answer_count += 1
		return answered_correctly

	def generate_activity(self):
		correct_answer = chr(random.randint(97,122))
		if self.play(correct_answer):
			self.good_effect()
		else:
			self.bad_effect()
